#
# spec file for package python-django-celery
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-django-celery
Version:        3.1.16
Release:        3.2
Url:            http://celeryproject.org
Summary:        Django Celery Integration
License:        BSD-3-Clause
Group:          Development/Languages/Python
Source:         https://pypi.python.org/packages/source/d/django-celery/django-celery-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python-devel
BuildRequires:  python-django
BuildRequires:  python-setuptools
#BuildRequires:  python-Sphinx
#BuildRequires:  python-sphinxcontrib-issuetracker
Requires:       python-celery >= 3.1.15
Requires:       python-celerymon
Requires:       python-django-picklefield
Requires:       python-tz
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
Django-celery provides Celery integration for Django. Using the Django
ORM and cache backend for storing results, autodiscovery of task
modules for applications listed in ``INSTALLED_APPS``, and more.

%prep
%setup -q -n django-celery-%{version}

%build
python setup.py build
# Building HTML docs currently not possible, needs internet access:
#cd docs && make html && rm .build/html/.buildinfo # Build HTML documentation

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
rm -rf %{buildroot}%{python_sitelib}/djcelery/tests # Don't ship tests

#%%check
#python setup.py test

%files
%defattr(-,root,root,-)
%doc AUTHORS LICENSE README
%{python_sitelib}/*

%changelog
* Sun May  3 2015 benoit.monin@gmx.fr
- update to version 3.1.16:
  * Fixed a problem with management commands hanging when djcelery
    is added to INSTALLED_APPS
- additional changes from version 3.1.15:
  * Now depends on Celery 3.1.15
  * Better Python 3 compatibility
  * Commands now disables model validation when using Django > 1.7
    (Issue #336)
  * No longer shadows the new --no-color option in Django 1.7
    Commands now have .stderr and .stdout attributes for Django 1.7
    compatibility
  * WorkerState.is_alive() is now accurate with USE_TZ enabled
- additional changes from version 3.1.10:
  * Test suite Django version compatibility fixes
  * Admin: Model forms now defines fields and exclude attributes
    (Issue #311)
  * Models: get_query_set renamed to get_queryset (but alias
    available) (Issue #308)
    Admin: Fixed bug in humanize.py
  * Support for Django 1.8's DiscoverRunner
  * Snapshot: Fixed time stamp timezone issue
- additional changes from version 3.1.9:
  * Now depends on Celery 3.1.9
  * TestSuiteRunner should now be working again
  * Database result backend now works with Python 3
  * The celery worker management command now gives a proper error
    message when positional arguments are provided
  * No longer uses manual transaction management to be compatible
    with Django 1.6
  * The celery management command now performs validation checks
    (Issue #253)
  * Url handlers: Fixed compatibility with Django 1.2
- additional changes from version 3.1.1:
  * Fixed Python 3 compatibility problems
  * Fixed compatibility with Django pre 1.6 (Issue #285)
  * celerycam: Fixed error when expire function returned None
    (Issue #210)
  * DatabaseScheduler: Now automatically disables periodic task if
    the schedule model it was connected is deleted (Issue #208)
  * Test runner now sets always eager settings on the app
    configuration. (Issue #201)
  * TaskRunnerStoringResults stored results in the wrong table
  * Celerycam: Fixed problem when USE_TZ not enabled
  * Celerycam: Fixed timezone problem with expires and eta (Issue
    [#275] + Issue #153)
  * Autodiscovery now warns instead of propagating import errors
    (Issue #226)
- additional changes from version 3.1.0:
  * Tests passing on Django 1.6
  * Now works with Celery 3.1
- increase required version of celery to 3.1.15
- remove examples and djcelerymon from package:
  not provided by upstream anymore
* Fri Sep 27 2013 p.drouand@gmail.com
- Update to version 3.0.23
  + Now depends on celery 3.0.23
  + ``djcelery.contrib.test_runner`` used naive datetimes
    resulting in ``RuntimeWarning`` (Issue #242).
  + Cache backend now compatible with Django 1.5.
  + DatabaseScheduler: Periodic task admin form now validates args and kwargs.
  + DatabaseScheduler: IntervalSchedule and CrontabSchedule will now be ordered
    in a more natural way.
  + Django Admin monitor:  Worker and Task now supports ``extra_context`.
  + Django Admin monitor: Now properly formats task tracebacks.
- Use source url as source
- Replace python-distribute with python-setuptools BuildRequires
* Wed Oct 10 2012 alexandre@exatati.com.br
- Update to 3.0.11:
  - Now depends on celery 3.0.11.
  - Now depends on pytz
  - Fixed Django Admin monitor timezone problem.
    Events still use timestamps that converts to the timezone of
    the receiving node, but a proper fix is being worked on that
    will be part of Celery 3.1
  - Fixed error in database close mechanism for Oracle.
    Fix contributed by Dan LaMotte.
* Fri Sep 21 2012 alexandre@exatati.com.br
- Update to 3.0.10:
  - Now depends on Celery 3.0.10
  - Fixed timezone issues when using the Database periodic task scheduler.
  - Admin: Periodic task form now adds tasks imported using CELERY_IMPORTS,
    and CELERY_INCLUDE.
  - Memory leak warning is now only output once.
  - Periodic task form in Admin no longer lists the celery built-in tasks.
* Fri Aug 31 2012 alexandre@exatati.com.br
- Update to 3.0.9:
  Important note:
  Celery 3.0.9 fixes an issue with periodic tasks and timezones.
  If you are using the database periodic task scheduler
  then you have to reset the `last_run_at` fields
  to ensure that no invalid timezones are stored:
    $ python manage.py shell
    >>> from djcelery.models import PeriodicTask
    >>> PeriodicTask.objects.update(last_run_at=None)
  - Now depends on Celery 3.0.9
    See the Celery changelog for more information:
    http://docs.celeryproject.org/en/latest/changelog.html
  - Don't close fds for database connections without a fileno.
  - Fixes Oracle compatibility issue for closing an already
    closed connection.
    Fix contributed by Dan LaMotte.
  - New test suite runner that stores results in the database:
    djcelery.contrib.test_runner.CeleryTestSuiteRunnerStoringResult.
    Contributed by Kirill Panshin.
* Fri Aug 17 2012 alexandre@exatati.com.br
- Update to 3.0.6:
  - Now depends on celery 3.0.6
  - Naive datetime's received by Celery are now assumed to be UTC.
  - The example demoproject no longer used djcelery.setup_loader.
  - Fixed south migration warning (Issue #149).
    Fix contributed by Roman Imankulov.
  - No longer uses deprecated urls module.
    Fix contributed by Simon Charette.
  - Databases are no longer closed after fork, instead we close
    the underlying file descriptors, so parent process can continue
    to use the connection (Issue #161).
    Fix contributed by Alex Stapleton.
* Thu Jul 26 2012 alexandre@exatati.com.br
- Update to 3.0.4:
  - Now depends on celery 3.0.4
  - CELERY_ENABLE_UTC is now disabled for Django versions
    before 1.4 (Issue #158).
  - celerycam: No longer overwrites name, args, kwargs and eta if the
    received event is missing (Issue #148 + Issue #155).
    Fix contributed by Kirill Panshin.
  - Fixed problem with migrations when running the tests.
    Fix contributed by Roger Barnes.
  - New utilities:
  - djcelery.common.respect_language
    Context manager for the with statement that changes the language used.
    For example:
    from celery import task
    from djcelery.common import respect_language
    @task
    def my_task(language=None):
    with respect_language(language):
    ...
  - djcelery.common.respects_language
    Decorator version of the above that adds a language keyword
    argument to any function that it decorates:
    @task
    @respects_language
    def my_task():
    pass
    my_task.delay(language=translation.get_language())
    Contributed by @ramusus
* Tue Jul 10 2012 alexandre@exatati.com.br
- Update to 3.0.1:
  Important Notes
  - --------------
  The 3.0 changelog forgot to mention that two of the database
  tables has been altered, so you must either use South to migrate
  the tables or alter the tables manually::
    ALTER TABLE celery_taskmeta
    ADD meta TEXT NULL DEFAULT "";
    ALTER TABLE djcelery_crontabschedule
    ADD day_of_month VARCHAR(64) NOT NULL DEFAULT "*";
    ALTER TABLE djcelery_crontabschedule
    ADD month_of_year VARCHAR(64) NOT NULL DEFAULT "*";
  Fixes
  - ----
  - Now depends on Celery 3.0.1
  - Fixes problems with South migrations (Issue #149)
    Fix contributed by Roman Imankulov.
  - Task monitor must store task eta in UTC (Issue #139).
    Fix contributed by Mike Ivanov.
* Sat Jul  7 2012 alexandre@exatati.com.br
- Update to 3.0.0:
  - Now depends on Celery 3.0
    It is important that you read the What's New document for the 3.0 series:
    http://docs.celeryproject.org/en/latest/whatsnew-3.0.html
  - No longer depends on django-picklefield
    And as such the result backend will no longer deepcopy return
    values or exceptions.
  - Celery 3.0 is the last release to require django-celery
    Starting with Celery 3.1 the django-celery package will no longer be
    required and Celery will support Django out of the box.
    The django-celery package may still exist for some time to provide
    additional utilities like the django-admin monitor.
  - django-celery 3.0 is the last series to support Python 2.5.
    Celery will no longer support Python 2.5 starting with version 2.7.
  - New manage.py celery umbrella command replaces older commands.
    All commands except for manage.py celeryevcam can
    now be started using the new umbrella command::
    $ manage.py celery worker -l info           # <<< NEW
    $ manage.py celeryd -l info                 # <-- OLD
    $ manage.py celery status                   # <<< NEW
    $ manage.py celeryctl status                # <-- OLD
    $ manage.py celery beat -l info             # <<< NEW
    $ manage.py celerybeat -l info              # <-- OLD
    $ manage.py celery multi start ...          # <<< NEW
    $ manage.py celeryd_multi start ...         # <-- OLD
    $ manage.py celery amqp queue.delete celery # <<< NEW
    $ manage.py camqadm queue.delete celery     # <-- OLD
    See manage.py celery help for a complete list of supported commands.
    The old commands will still work, but you are encouraged to start
    using the new umbrella command.
  - The distribution contrib/ directory is now renamed to
    extra/.
  - The django-celery source code repository has moved
    The new location is at http://github.com/celery/django-celery
* Thu Apr 19 2012 alexandre@exatati.com.br
- Update to 2.5.5:
  * Fixed bug where task modules were not imported.
* Mon Apr 16 2012 alexandre@exatati.com.br
- Update to 2.5.4:
  * Compatibility with celery 2.5.3
  * Database scheduler now imports exchange, routing_key and queue
    options from CELERYBEAT_SCHEDULE.
* Fri Apr 13 2012 alexandre@exatati.com.br
- Update to 2.5.3:
  * 2.5.2 release broke installation because of an import in the package.
    Fixed by not having setup.py import the djcelery module anymore,
    but rather parsing the package file for metadata.
* Fri Apr 13 2012 alexandre@exatati.com.br
- Update to 2.5.2:
  * PeriodicTask admin now lists the enabled field in the list view
    Contributed by Gabe Jackson.
  * Fixed a compatibility issue with Django < 1.3
    Fix contributed by Roman Barczyski
  * Admin monitor now properly escapes args and kwargs.
    Fix contributed by Serj Zavadsky
  * PeriodicTask admin now gives error if no schedule set (or both set)
    (Issue #126).
  * examples/demoproject has been updated to use the Django 1.4 template.
  * Database connection is no longer closed for eager tasks (Issue #116).
    Fix contributed by Mark Lavin.
  * The first-steps document for django-celery has been moved to the main
    Celery documentation.
  * djcelerymon command no longer worked properly, this has now been fixed
    (Issue #123).
- Now it requires python-celery to build.
* Wed Mar 21 2012 saschpe@gmx.de
- Spec file cleanup:
  * Simplified macro usage
  * Don't install tests
  * Require python-celerymon
* Tue Mar 13 2012 cfarrell@suse.com
- license update: BSD-3-Clause
  SPDX format
* Thu Mar  1 2012 alexandre@exatati.com.br
- Update to 2.5.1:
  * Now depends on Celery 2.5.1
  * Fixed problem with recursive imports when USE_I18N was enabled
    (Issue #109).
  * The CELERY_DB_REUSE_MAX setting was not honored.
  * The djcelerymon command no longer runs with DEBUG.
    To enable debug you can set the DJCELERYMON_DEBUG
    environment variable.
  * Fixed eventlet/gevent compatability with Django 1.4's new thread
    sharing detection.
  * Now depends on django-picklefield 0.2.0 or greater.
    Previous versions would not work correctly with Django 1.4.
* Fri Feb 24 2012 alexandre@exatati.com.br
- Update to 2.5.0:
  * Now depends on Celery 2.5.
  * Database schema has been updated.
  * Auto-discovered task modules now works with the new auto-reloader
    functionality.
  * The database periodic task scheduler now tried to recover from
    operational database errors.
  * The periodic task schedule entry now accepts both int and
    timedelta (Issue #100).
  * 'Connection already closed' errors occurring while closing
    the database connection are now ignored (Issue #93).
  * The ``djcelerymon`` command used to start a Django admin monitor
    instance outside of Django projects now starts without a celery
    config module.
  * Should now work with Django 1.4's new timezone support.
    Contributed by Jannis Leidel and Donald Stufft.
  * South migrations did not work properly.
    Fix contributed by Christopher Grebs.
  * celeryd-multi now preserves django-related arguments,
    like ``--settings`` (Issue #94).
  * Migrations now work with Django < 1.3 (Issue #92).
    Fix contributed by Jude Nagurney.
  * The expiry of the database result backend can now be an int (Issue #84).
* Mon Nov 14 2011 alexandre@exatati.com.br
- Update to 2.4.2:
  - Fixed syntax error in South migrations code (Issue #88).
* Mon Nov  7 2011 alexandre@exatati.com.br
- Update to 2.4.1:
  * Management commands was missing command line arguments because of recent
    changes to Celery.
  * Management commands now supports the --broker|-b option.
  * South migrations now ignores errors when tables already exist.
* Fri Nov  4 2011 alexandre@exatati.com.br
- Update t0 2.4.0:
  This release adds South migrations, which well assist users in
  automatically updating their database schemas with each
  django-celery release.
  - Now depends on Celery 2.4.0 or higher.
  - South migrations have been added.
  - Test runner now compatible with Django 1.4.
- Please read Upgrade Instructions:
  http://packages.python.org/django-celery/changelog.html#upgrading-for-south-users
* Mon Aug 22 2011 alexandre@exatati.com.br
- Update to 2.3.3:
  - Precedence issue caused database backend tables to not be
    created (Issue #62).
* Sat Aug 20 2011 alexandre@exatati.com.br
- Update to 2.3.2:
  - Fixes circular import of DatabaseBackend.
* Thu Aug 11 2011 alexandre@exatati.com.br
- Update to 2.3.1:
  - Django database result backend tables were not created.
* Fri Aug  5 2011 alexandre@exatati.com.br
- Update to 2.3.0:
  - Now depends on Celery 2.3.0.
- Regenerate spec file with py2pack.
* Fri Jul  1 2011 appleonkel@opensuse.org
- Changed require from exact version to python-celery >= %%{version}.
* Sun Feb 20 2011 alexandre@exatati.com.br
- Update to 2.2.4:
  * celerybeat: DatabaseScheduler would not react to changes when using MySQL and
    the default transaction isolation level REPEATABLE-READ (Issue #41).
    It is still recommended that you use isolation level READ-COMMITTED
    (see the Celery FAQ).
* Sat Feb 12 2011 alexandre@exatati.com.br
- Update to 2.2.3:
  * celerybeat: DatabaseScheduler did not respect the disabled
    setting after restart.
  * celeryevcam: Expiring objects now works on PostgreSQL.
  * Now requires Celery 2.2.3
* Thu Feb  3 2011 alexandre@exatati.com.br
- Update to 2.2.2:
  * Now requires Celery 2.2.2
  * Periodic Task Admin broke if the CELERYBEAT_SCHEDULE setting
    was not set.
  * DatabaseScheduler No longer creates duplicate interval models.
  * The djcelery admin templates were not included in the
    distribution.
* Wed Feb  2 2011 alexandre@exatati.com.br
- Update to 2.2.1:
  * Should now work with Django versions previous to 1.2.
* Tue Feb  1 2011 alexandre@exatati.com.br
- Update to 2.2.0:
  * Now depends on Celery v2.2.0
  * djceleryadm: Adds task actions Kill and Terminate task
  * celerycam: Django's queryset.delete() fetches everything in
    memory THEN deletes, so we need to use raw SQL to expire objects.
  * djcelerymon: Added Command.stdout + Command.stderr  (Issue #23).
  * Need to close any open database connection after any embedded
    celerybeat process forks.
  * Added contrib/requirements/py25.txt
  * Demoproject now does ``djcelery.setup_loader`` in settings.py.
* Sat Dec  4 2010 alexandre@exatati.com.br
- Update to 2.1.4:
  * `djcelerymon`: Optimized the SQL queries used when displaying the task list.
  * `Admin`: Add a warning to the Edit Periodic Task page if the database
    scheduler is not used (Note: To remove this warning you can't just use
    the `-S` argument to `celerybeat`, but have to set the
    `CELERYBEAT_SCHEDULER` setting).
  * demoproject: Use database backend by default, and call
    `djcelery.setup_loader` in settings.
  * `DatabaseScheduler`: Properly handle periodic tasks being removed from
    the database.
  * `DatabaseScheduler`: Added `ModelEntry._default_now` to provide the default
    value for when `last_run_at` is not set.
* Fri Oct 29 2010 alexandre@exatati.com.br
- Update to 2.1.2.
* Thu Oct 14 2010 alexandre@exatati.com.br
- Update to 2.1.1.
* Sat Oct  9 2010 alexandre@exatati.com.br
- Update to 2.1.0.
* Thu Sep 16 2010 alexandre@exatati.com.br
- Update to 2.0.3.
* Fri Jul 30 2010 alexandre@exatati.com.br
- Update to 2.0.2.
* Tue Jun 29 2010 poeml@cmdline.net
- fix requirement on the picklefield module (missing 'django' in
  python-django-picklefield package name)
* Wed Jun 23 2010 alexandre@exatati.com.br
- Initial package (1.1.1) for openSUSE.
